import twill
import datetime
import utils

def setup():
    '''Set up test form with date widget'''
    utils.login('admin')
    twill.execute_string('''
go http://localhost:10003/admin/forms/new
fv 1 name date
submit

fv 1 label date
fv 1 type 'Date'
submit
''')

def teardown():
    '''Tear down form'''
    twill.execute_string('''
go http://localhost:10003/admin/forms/1/delete
submit
''')
    utils.logout()

def test_fill_base_form():
    '''Date widget: basis'''
    twill.execute_string('''
go http://localhost:10003/date
fv 1 f1 2009-10-13
submit
find 'Check values'
''')

def test_minimum_date():
    '''Date widget: minimum date'''
    twill.execute_string('''
go http://localhost:10003/admin/forms/1/fields/1/
fv 1 minimum_date 2009-10-13
fv 1 minimum_is_future False
fv 1 maximum_date ''
fv 1 date_in_the_past False
fv 1 date_can_be_today False
submit Submit

go http://localhost:10003/date
fv 1 f1 2009-10-10
submit
find 'There were errors'
fv 1 f1 2009-10-13
submit
find 'Check values'
''')

def test_maximum_date():
    '''Date widget: maximum date'''
    twill.execute_string('''
go http://localhost:10003/admin/forms/1/fields/1/
fv 1 minimum_date ''
fv 1 minimum_is_future False
fv 1 maximum_date 2009-10-13
fv 1 date_in_the_past False
fv 1 date_can_be_today False
submit Submit

go http://localhost:10003/date
fv 1 f1 2009-10-15
submit
find 'There were errors'
fv 1 f1 2009-10-11
submit
find 'Check values'
''')

def test_future_date():
    '''Date widget: future date'''
    today = datetime.datetime.today()
    future = today + datetime.timedelta(2)
    past = today - datetime.timedelta(2)
    twill.execute_string('''
go http://localhost:10003/admin/forms/1/fields/1/
fv 1 minimum_date ''
fv 1 minimum_is_future True
fv 1 maximum_date ''
fv 1 date_in_the_past False
fv 1 date_can_be_today False
submit Submit

go http://localhost:10003/date
fv 1 f1 %(today)s
submit
find 'There were errors'
fv 1 f1 %(past)s
submit
find 'There were errors'
fv 1 f1 %(future)s
submit
find 'Check values'
''' % {'today': today.strftime('%Y-%m-%d'),
       'future': future.strftime('%Y-%m-%d'),
       'past': past.strftime('%Y-%m-%d')})

def test_past_date():
    '''Date widget: past date'''
    today = datetime.datetime.today()
    future = today + datetime.timedelta(2)
    past = today - datetime.timedelta(2)
    twill.execute_string('''
go http://localhost:10003/admin/forms/1/fields/1/
fv 1 minimum_date ''
fv 1 minimum_is_future False
fv 1 maximum_date ''
fv 1 date_in_the_past True
fv 1 date_can_be_today False
submit Submit

go http://localhost:10003/date
fv 1 f1 %(today)s
submit
find 'There were errors'
fv 1 f1 %(future)s
submit
find 'There were errors'
fv 1 f1 %(past)s
submit
find 'Check values'
''' % {'today': today.strftime('%Y-%m-%d'),
       'future': future.strftime('%Y-%m-%d'),
       'past': past.strftime('%Y-%m-%d')})

def test_future_or_today_date():
    '''Date widget: today or future date'''
    today = datetime.datetime.today()
    future = today + datetime.timedelta(2)
    past = today - datetime.timedelta(2)
    twill.execute_string('''
go http://localhost:10003/admin/forms/1/fields/1/
fv 1 minimum_date ''
fv 1 minimum_is_future True
fv 1 maximum_date ''
fv 1 date_in_the_past False
fv 1 date_can_be_today True
submit Submit

go http://localhost:10003/date
fv 1 f1 %(today)s
submit
find 'Check values'
submit previous
fv 1 f1 %(past)s
submit
find 'There were errors'
fv 1 f1 %(future)s
submit
find 'Check values'
''' % {'today': today.strftime('%Y-%m-%d'),
       'future': future.strftime('%Y-%m-%d'),
       'past': past.strftime('%Y-%m-%d')})

def test_past_or_today_date():
    '''Date widget: today or past date'''
    today = datetime.datetime.today()
    future = today + datetime.timedelta(2)
    past = today - datetime.timedelta(2)
    twill.execute_string('''
go http://localhost:10003/admin/forms/1/fields/1/
fv 1 minimum_date ''
fv 1 minimum_is_future False
fv 1 maximum_date ''
fv 1 date_in_the_past True
fv 1 date_can_be_today True
submit Submit

go http://localhost:10003/date
fv 1 f1 %(today)s
submit
find 'Check values'
submit previous
fv 1 f1 %(future)s
submit
find 'There were errors'
fv 1 f1 %(past)s
submit
find 'Check values'
''' % {'today': today.strftime('%Y-%m-%d'),
       'future': future.strftime('%Y-%m-%d'),
       'past': past.strftime('%Y-%m-%d')})

