# w.c.s. - web application for online forms
# Copyright (C) 2005-2012  Entr'ouvert
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.

from quixote.html import htmltext, TemplateIO
from qommon.form import *


data_source_functions = {}

def register_data_source_function(function, function_name=None):
    if not function_name:
        function_name = function.__name__
    if not function_name in data_source_functions:
        data_source_functions[function_name] = function


class DataSourceSelectionWidget(CompositeWidget):
    def __init__(self, name, value = None, **kwargs):
        CompositeWidget.__init__(self, name, value, **kwargs)

        if not value:
            value = {}

        options = [('none', _('None')),
                   ('formula', _('Formula (Python)'))]

        self.add(SingleSelectWidget, 'type', options = options, value = value.get('type'))

        self.parse()
        if not self.value:
            self.value = {}

        if self.value.get('type') == 'formula':
            self.add(StringWidget, 'value', value = value.get('value'))

        self.add(SubmitWidget, 'apply', value = _('Apply'))

        self._parsed = False


    def _parse(self, request):
        values = {}
        for name in ('type', 'value'):
            value = self.get(name)
            if value:
                values[name] = value
        if values.get('type', '') == 'none':
            values = None
        self.value = values or None

    def render_content(self):
        r = TemplateIO(html=True)
        for widget in self.get_widgets():
            r += widget.render_content()
        return r.getvalue()


def get_items(data_source):
    if data_source.get('type') == 'formula':
        vars = get_publisher().substitutions.get_context_variables()
        try:
            return eval(data_source.get('value'), vars, data_source_functions)
        except:
            return []
    return []
