# w.c.s. - web application for online forms
# Copyright (C) 2005-2011  Entr'ouvert
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, see <http://www.gnu.org/licenses/>.

import sys

from qommon.form import *

from wcs.workflows import WorkflowStatusJumpItem, register_item_class


class JumpWorkflowStatusItem(WorkflowStatusJumpItem):
    description = N_('Change Status Automatically')
    key = 'jump'
    waitpoint = False

    condition = None

    def render_as_line(self):
        if self.status:
            wf_status = self.get_status()
            if not wf_status:
                return _('Change Status Automatically (broken)')
            if self.condition:
                return _('Change Status Automatically (to %(name)s, if %(condition)s)') % {
                            'name': wf_status.name,
                            'condition': self.condition
                        }
            else:
                return _('Change Status Automatically (to %s)') % wf_status.name
        else:
            return _('Change Status Automatically (not completed)')

    def get_parameters(self):
        return ('status', 'condition')

    def add_parameters_widgets(self, form, parameters, prefix='', formdef=None):
        WorkflowStatusJumpItem.add_parameters_widgets(self, form, parameters, prefix, formdef)
        if 'condition' in parameters:
            form.add(StringWidget, '%scondition' % prefix, title=_('Condition (formula)'),
                     value=self.condition, size=40)

    def perform(self, formdata):
        if not self.status:
            return
        condition = True
        if self.condition:
            variables = get_publisher().substitutions.get_context_variables()
            try:
                condition = eval(self.condition, get_publisher().get_global_eval_dict(), variables)
            except:
                get_publisher().notify_of_exception(sys.exc_info())
                condition = False
        if condition:
            wf_status = self.get_status()
            if wf_status:
                formdata.status = 'wf-%s' % wf_status.id

register_item_class(JumpWorkflowStatusItem)
